create table chief.members
      (mbr_id        uuid not null default gen_random_uuid()
      ,last_name     text not null
      ,first_name    text not null
      ,start_date    date not null default now()
      ,constraint mbr_pk primary key (mbr_id)
      ,constraint mbr_bk unique (last_name, first_name)
      )
;
comment on table chief.members is 'Alias: MBR - Master list of user group and focus group members.';      

create table chief.groups
      (grp_id        uuid not null default gen_random_uuid()
      ,name          text not null
      ,description   text
      ,url           text
      ,constraint grp_pk primary key (grp_id)
      ,constraint grp_bk unique (name)
      )
;      
comment on table chief.groups is 'Alias: GRP - Repository of groups within the overall user group. Includes group names, descriptions and URLs.';

create table chief.events
      (evnt_id       uuid not null default gen_random_uuid()
      ,grp_id        uuid not null
      ,name          text not null
      ,description   text
      ,constraint evnt_pk primary key (evnt_id)
      ,constraint evnt_bk unique (grp_id, name)
      ,constraint evnt2grp_fk foreign key (grp_id) references chief.groups (grp_id)
      )
;
comment on table chief.events is 'Alias: EVNT - Master list of event names and descriptions owned by each group. These events will be referenced in the event_calendar as events are scheduled.';    

create table chief.group_members
      (gmbr_id       uuid not null default gen_random_uuid()
      ,grp_id        uuid not null
      ,mbr_id        uuid not null
      ,start_date    date not null
      ,end_date      date
      ,constraint gmbr_pk primary key (gmbr_id)
      ,constraint gmbr_bk unique (grp_id, mbr_id)
      ,constraint gmbr2grp_fk foreign key (grp_id) references chief.groups (grp_id)
      ,constraint gmbr2mbr_fk foreign key (mbr_id) references chief.members (mbr_id)
      )
;
comment on table chief.group_members is 'Alias: GMBR - Associates groups and their members to define which members belond to which groups.';

create table chief.event_calendar
      (ecal_id       uuid not null default gen_random_uuid()
      ,evnt_id       uuid not null
      ,topic         text
      ,start_time    timestamp without time zone not null
      ,end_time      timestamp without time zone not null
      ,evnt_link     text
      ,constraint ecal_pk primary key (ecal_id)
      ,constraint ecal_bk unique (evnt_id, start_time)
      ,constraint ecal2evnt_fk foreign key (evnt_id) references chief.events (evnt_id)
      )
;
comment on table chief.event_calendar is 'Alias: ECAL - Calendar of events for all groups.';      














      
