create view devops.members
as
select last_name
      ,first_name
      ,start_date  
      ,mbr_id
  from chief.members
;
comment on view devops.members is 'Alias: MBR - Master list of user group and focus group members.';      

create view devops.groups
as
select name
      ,description
      ,url
      ,grp_id
  from chief.groups
;      
comment on view devops.groups is 'Alias: GRP - Repository of groups within the overall user group. Includes group names, descriptions and URLs.';

create view devops.events
as
select evnt.name         evnt_name
      ,evnt.description  evnt_description
      ,grp.name          grp_name
      ,grp.description   grp_description
      ,evnt.evnt_id      evnt_id
      ,evnt.grp_id       grp_id
  from chief.events  evnt
       join chief.groups grp
               on grp.grp_id = evnt.grp_id
;
comment on view devops.events is 'Alias: EVNT - Master list of event names and descriptions owned by each group. These events will be referenced in the event_calendar as events are scheduled.';    

create view devops.group_members
as
select grp.name          grp_name
      ,grp.description   grp_description
      ,mbr.last_name     mbr_last_name
      ,mbr.first_name    mbr_first_name
      ,to_char(gmbr.start_date, 'yyyy-mm-dd')   gmbr_start_date
      ,to_char(gmbr.end_date, 'yyyy-mm-dd')     gmbr_end_date
      ,gmbr.gmbr_id      gmbr_id
      ,gmbr.grp_id       grp_id
      ,gmbr.mbr_id       mbr_id
  from chief.group_members  gmbr
       join chief.members  mbr
               on mbr.mbr_id = gmbr.mbr_id
       join chief.groups  grp
               on grp.grp_id = gmbr.grp_id
;
comment on view devops.group_members is 'Alias: GMBR - Associates groups and their members to define which members belond to which groups.';

create view devops.event_calendar
as
select ecal.topic        topic
      ,to_char(ecal.start_time, 'yyyy-mm-dd hh:mi am')   start_time    
      ,to_char(ecal.end_time, 'yyyy-mm-dd hh:mi am')     end_time
      ,ecal.evnt_link    evnt_link
      ,evnt.name         evnt_name
      ,evnt.description  evnt_description
      ,grp.name          grp_name
      ,grp.description   grp_description
      ,ecal.ecal_id      ecal_id
      ,ecal.evnt_id      evnt_id
      ,grp.grp_id        grp_id
  from chief.event_calendar  ecal
       join chief.events  evnt
               on evnt.evnt_id = ecal.evnt_id
       join chief.groups  grp
               on grp.grp_id = evnt.grp_id
;
comment on view devops.event_calendar is 'Alias: ECAL - Calendar of events for all groups.';      









