#!/bin/sh
# --------------------------------------------------------------------------------
# Filename:	      ug_install.sh
# Description:	      Execute DDL and Copy scripts to build new ug database.
# Preconditions:      New database owner superuser role must already exist in /home/repositories/.pgpass
#                     including    host:port:db_name:user_name:password
#                     Example:     127.0.0.1:5432:ug:ug_user:'12f058a1fa88c48dc78fbb5ade2a52bf'
# Parameters:	      SCRIPTNAME   Name of DDL or Copy script to be executed in /home/dbzone/ug/scripts      
# Usage:	      ug_install.sh [SCRIPTNAME]
#			 	   Example:  ug_install.sh ug_02_tables.ddl
# Author:             Susan E Hurst
# Creation Date:      2022-11-12
# Copyright:          Brookhurst Data LLC - Copyright 2022 - All rights reserved
# Revision History:
# Date:	        Editor:		    Description:
# -----------	---------------	--------------------------------------------------
# 		
# 2022-11-12 	Susan Hurst	    Initial creation
# --------------------------------------------------------------------------------
set -x
#-- Assign values to working variables
SCRIPTNAME=$1

#-- Source .pgpass file
. /home/dbzone/.pgpass

#-- Execute scripts from /usr/home/dbzone/ug/scripts
cd /home/dbzone/ug/scripts

echo "Executing script: ${SCRIPTNAME}."
psql -d ug -U ug -f "${SCRIPTNAME}"

#-- We're done!

